@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
 from pygismeteo_base.models import (
     current,
     search_by_coordinates,
     search_by_ip,
     search_by_query,
-    step3or6,
+    step3,
+    step6,
     step24,
 )
 
@@ -13,6 +13,7 @@ __all__ = (
     "search_by_coordinates",
     "search_by_ip",
     "search_by_query",
-    "step3or6",
+    "step3",
+    "step6",
     "step24",
 )
