@@ -14,9 +14,9 @@ class SubDistrict(BaseModel):
 
 
 class Country(BaseModel):
-    name: str
+    name: Optional[str]
     code: str
-    name_p: str = Field(..., alias="nameP")
+    name_p: Optional[str] = Field(..., alias="nameP")
 
 
 class ModelItem(BaseModel):
@@ -24,8 +24,8 @@ class ModelItem(BaseModel):
     id: int
     sub_district: Optional[SubDistrict]
     url: str
-    name_p: str = Field(..., alias="nameP")
-    name: str
+    name_p: Optional[str] = Field(..., alias="nameP")
+    name: Optional[str]
     distance: float
     kind: str
     country: Country
